{% extends 'data/data_map.html' %}{% load humanize %}
{% load staticfiles %}

{% block head_css_extra %}
<link rel="stylesheet" href="//cdn.leafletjs.com/leaflet-0.6.4/leaflet.css" />
<!--[if lte IE 8]>
    <link rel="stylesheet" href="//cdn.leafletjs.com/leaflet-0.6.4/leaflet.ie.css" />
<![endif]-->
<link href="{% static 'css/vendor/leaflet.label.css' %}" rel="stylesheet" />
{% endblock %}

{% block body %}
<div id="map-controls" class="clearfix">
    <header class="box-header">
        <a class="title" href="{% url 'homepage' %}">
            <img src="{% static 'img/wazi-logo.png' %}"> {{ WAZIMAP.name }}
        </a>
    </header>
    <div class="box-content">
        <section class="clearfix">
            {% include 'data/_blocks/_toggle_menu.html' %}
            {% include 'data/_blocks/_topic_select_input.html' %}
        </section>

        <section id="data-display" class="clearfix">
            <div id="header-container"></div>
        </section>
        <aside></aside>
    </div>
</div>

<div id="slippy-map"></div>
{% endblock %}

{% block page_specific_javascript %}
{{ block.super }}
<script src="{% static 'js/vendor/topojson.v1.min.js' %}"></script>
{% endblock %}
