{% extends 'data/_base_data.html' %}{% load humanize %}
{% load staticfiles %}

{% block head_title %}Map View: {{ block.super }}{% endblock %}

{% block head_css_extra %}
<link href='http://api.tiles.mapbox.com/mapbox.js/v1.6.1/mapbox.css' rel='stylesheet' />
  <!--[if lte IE 8]>
    <link href='http://api.tiles.mapbox.com/mapbox.js/v1.6.1/mapbox.ie.css' rel='stylesheet' >
  <![endif]-->
<link href='{{STATIC_URL}}css/vendor/leaflet.label.css' rel='stylesheet' />
{% endblock %}

{% block body_class %}{{ block.super }} full-screen{% endblock %}

{% block body %}
<div id="map-controls" class="clearfix">
    <header class="box-header">
        <a class="title" href="{% url 'homepage' %}">
				<img src="{% static 'img/wazi-logo.png' %}"> Wazimap
        </a>
    </header>
    <div class="box-content">
        <section class="clearfix">
            {% include 'data/_blocks/_toggle_menu.html' %}
            {% include 'data/_blocks/_topic_select_input.html' %}
        </section>

        <section id="data-display" class="clearfix">
            <div id="header-container"></div>
        </section>
        <aside></aside>
    </div>
</div>

<div id="slippy-map"></div>
{% endblock %}

{% block page_specific_javascript %}
<script src="//cdn.leafletjs.com/leaflet-0.6.4/leaflet.js"></script>
<script src="{% static 'js/vendor/leaflet.label.js' %}"></script>
{% endblock %}
