{% extends 'topics/_base_topics.html' %}

{% block content %}
<section id="topic-overview">
{% include "topics/_question_aside.html" %}    
<h2>Overview</h2>
<p>These tables address the topic of poverty.
Some table names have been simplified. References to poverty status/level or receipt of food stamps/SNAP are always for the last 12 months.
</p>
<table>
<thead><tr>
<th>Code</th>
<th>Title</th>
</tr></thead>
<tbody>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17001' %}">B17001</a><sup>†‡</sup></strong></td>
<td>Poverty Status by Sex by Age</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17002' %}">B17002</a><sup>‡</sup></strong></td>
<td>Ratio of Income to Poverty Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17003' %}">B17003</a><sup>‡</sup></strong></td>
<td>Poverty Status of Individuals by Sex by Educational Attainment</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17004' %}">B17004</a><sup>‡</sup></strong></td>
<td>Poverty Status of Individuals by Sex by Work Experience</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17005' %}">B17005</a></strong></td>
<td>Poverty Status of Individuals by Sex by Employment Status</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17006' %}">B17006</a><sup>‡</sup></strong></td>
<td>Poverty Status of Related Children Under 18 Years by Family Type by Age of Related Children Under 18 Years</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17007' %}">B17007</a><sup>‡</sup></strong></td>
<td>Poverty Status of Unrelated Individuals 15 Years and Over by Sex by Age</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17008' %}">B17008</a></strong></td>
<td>Aggregate Income Deficit (Dollars) of Unrelated Individuals by Sex</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17009' %}">B17009</a><sup>‡</sup></strong></td>
<td>Poverty Status by Work Experience of Unrelated Individuals by Householder Status</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17010' %}">B17010</a><sup>†‡</sup></strong></td>
<td>Poverty Status of Families by Family Type by Presence of Related Children Under 18 Years by Age of Related Children</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17011' %}">B17011</a></strong></td>
<td>Aggregate Income Deficit (Dollars) for Families by Family Type</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17012' %}">B17012</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Household Type by Number of Related Children Under 18 Years</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17013' %}">B17013</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Household Type by Number of Persons in Family</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17014' %}">B17014</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Household Type by Number of Workers in Family</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17015' %}">B17015</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Family Type by Social Security Income by Supplemental Security Income (SSI) and Cash Public Assistance Income</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17016' %}">B17016</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Family Type by Work Experience of Householder and Spouse</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17017' %}">B17017</a><sup>‡</sup></strong></td>
<td>Poverty Status by Household Type by Age of Householder</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17018' %}">B17018</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Household Type by Educational Attainment of Householder</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17019' %}">B17019</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Household Type by Tenure</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17020' %}">B17020</a><sup>ª</sup></strong></td>
<td>Poverty Status by Age (racial iterations)</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17021' %}">B17021</a><sup>‡</sup></strong></td>
<td>Poverty Status of Individuals by Living Arrangement</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17022' %}">B17022</a><sup>‡</sup></strong></td>
<td>Ratio of Income to Poverty Level of Families by Family Type by Presence of Related Children Under 18 Years by Age of Related Children</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17023' %}">B17023</a><sup>‡</sup></strong></td>
<td>Poverty Status of Families by Household Type by Number of Own Children Under 18 Years</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17024' %}">B17024</a><sup>‡</sup></strong></td>
<td>Age by Ratio of Income to Poverty Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17025' %}">B17025</a><sup>‡</sup></strong></td>
<td>Poverty Status by Nativity</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B17026' %}">B17026</a><sup>‡</sup></strong></td>
<td>Ratio of Income to Poverty Level of Families</td>
</tr>
</tbody>
<tfoot>
        <tr class="help-text">
            <td colspan="2">
                <sup>‡</sup>Table also available in "collapsed" version: change "B" to "C" for table code.<br>
                <sup>†</sup>Also available in <a href="{% url 'topic_detail' 'race-latino' %}#topic-elsewhere">racial iterations</a>.<br>
                <sup>ª</sup>No basic table is offered–only <a href="{% url 'topic_detail' 'race-latino' %}#topic-elsewhere">racial iteration</a> tables.<br>
            </td>
        </tr>
    </tfoot>
</table>
<h2>Other ACS Tables Referencing Poverty</h2>
<p>Some table names below have been simplified. References to poverty status/level or receipt of food stamps/SNAP are always for the last 12 months.</p>
<table>
<thead><tr>
<th>Code</th>
<th>Title</th>
</tr></thead>
<tbody>
<tr>
<td><strong><a href="{% url 'table_detail' 'B05010' %}">B05010</a><sup>†</sup></strong></td>
<td>Ratio of Income to Poverty Level by Nativity of Children Under 18 Years in Families and Subfamilies by Living Arrangements and Nativity of Parents</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B06012' %}">B06012</a></strong></td>
<td>Place of Birth by Poverty Status in the United States</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B07012' %}">B07012</a></strong></td>
<td>Geographical Mobility in the Past Year by Poverty Status for Current Residence in the United States</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B07412' %}">B07412</a></strong></td>
<td>Geographical Mobility in the Past Year by Poverty Status for Residence 1 Year Ago in the United States</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08122' %}">B08122</a><sup>†</sup></strong></td>
<td>Means of Transportation to Work by Poverty Status</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08522' %}">B08522</a><sup>†</sup></strong></td>
<td>Means of Transportation to Work by Poverty Status for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B10059' %}">B10059</a></strong></td>
<td>Poverty Status of Grandparents Living With Own Grandchildren Under 18 Years by Responsibility for Own Grandchildren and Age of Grandparent</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B13010' %}">B13010</a></strong></td>
<td>Women 15 to 50 Years Who Had a Birth in the Past 12 Months by Marital Status and Poverty Status</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B14006' %}">B14006</a><sup>†</sup></strong></td>
<td>Poverty Status by School Enrollment by Level of School for the Population 3 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B15004' %}">B15004</a></strong></td>
<td>Poverty Status by Sex by Educational Attainment for the Population 25 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B16009' %}">B16009</a><sup>†</sup></strong></td>
<td>Poverty Status by Age by Language Spoken at Home for the Population 5 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18030' %}">B18030</a><sup>†</sup></strong></td>
<td>Disability Status by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 5 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18031' %}">B18031</a><sup>†</sup></strong></td>
<td>Sensory Disability by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 5 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18032' %}">B18032</a><sup>†</sup></strong></td>
<td>Physical Disability by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 5 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18033' %}">B18033</a><sup>†</sup></strong></td>
<td>Mental Disability by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 5 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18034' %}">B18034</a><sup>†</sup></strong></td>
<td>Self-care Disability by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 5 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18035' %}">B18035</a><sup>†</sup></strong></td>
<td>Go-outside-home Disability by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 16 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18036' %}">B18036</a><sup>†</sup></strong></td>
<td>Employment Disability by Sex by Age by Poverty Status for the Civilian Noninstitutionalized Population 16 to 64 Years</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18130' %}">B18130</a><sup>†</sup></strong></td>
<td>Age by Disability Status by Poverty Status</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B18131' %}">B18131</a><sup>†</sup></strong></td>
<td>Age by Ratio of Income to Poverty Level by Disability Status and Type</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B21006' %}">B21006</a><sup>†</sup></strong></td>
<td>Age by Veteran Status by Poverty Status by Disability Status for the Civilian Population 18 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B21007' %}">B21007</a><sup>†</sup></strong></td>
<td>Age by Veteran Status by Poverty Status by Disability Status for the Civilian Population 18 Years and Over</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B22003' %}">B22003</a></strong></td>
<td>Receipt of Food Stamps/SNAP by Poverty Status for Households</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B22005' %}">B22005</a><sup>ª</sup></strong></td>
<td>Receipt of Food Stamps/SNAP by Race of Householder</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B23005' %}">B23005</a></strong></td>
<td>Poverty Status by Disability Status by Employment Status for the Population 20 to 64 Years</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B23024' %}">B23024</a></strong></td>
<td>Poverty Status by Disability Status by Employment Status for the Population 20 to 64 Years</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B27016' %}">B27016</a><sup>†</sup></strong></td>
<td>Health Insurance Coverage Status and Type by Ratio of Income to Poverty Level by Age</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B27017' %}">B27017</a><sup>†</sup></strong></td>
<td>Private Health Insurance by Ratio of Income to Poverty Level by Age</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B27018' %}">B27018</a><sup>†</sup></strong></td>
<td>Public Health Insurance by Ratio of Income to Poverty Level by Age</td>
</tr>
</tbody>
<tfoot>
        <tr class="help-text">
            <td colspan="2">
                <sup>†</sup>Also available in <a href="{% url 'topic_detail' 'race-latino' %}#topic-elsewhere">racial iterations</a>.<br>
                <sup>ª</sup>No basic table is offered–only <a href="{% url 'topic_detail' 'race-latino' %}#topic-elsewhere">racial iteration</a> tables.<br>
            </td>
        </tr>
    </tfoot>
</table>
</section>
{% endblock %}


